# Generated by Django 4.2 on 2024-09-27 18:15

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ("contenttypes", "0002_remove_content_type_name"),
        ("django_notification", "0001_initial"),
    ]

    operations = [
        migrations.AlterField(
            model_name="deletednotification",
            name="deleted_at",
            field=models.DateTimeField(
                db_comment="Timestamp recording when the user deleted the notification.",
                default=django.utils.timezone.now,
                help_text="The time when the notification was deleted.",
                verbose_name="Deleted at",
            ),
        ),
        migrations.AlterField(
            model_name="deletednotification",
            name="notification",
            field=models.ForeignKey(
                db_comment="Foreign key linking to the Notification model, representing the notification that was soft-deleted by the user.",
                help_text="The notification that was deleted.",
                on_delete=django.db.models.deletion.CASCADE,
                related_name="deleted",
                to="django_notification.notification",
                verbose_name="Notification",
            ),
        ),
        migrations.AlterField(
            model_name="deletednotification",
            name="user",
            field=models.ForeignKey(
                db_comment="Foreign key linking to the User model (AUTH_USER_MODEL), representing the user who marked the notification as deleted.",
                help_text="The user who deleted the notification.",
                on_delete=django.db.models.deletion.CASCADE,
                related_name="deleted_notifications",
                to=settings.AUTH_USER_MODEL,
                verbose_name="User",
            ),
        ),
        migrations.AlterField(
            model_name="notification",
            name="action_object_content_type",
            field=models.ForeignKey(
                blank=True,
                db_comment="The content type of the action object that triggered the notification, if applicable.",
                help_text="The content type of the action object.",
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="action_content_type_notifications",
                to="contenttypes.contenttype",
                verbose_name="Action object ContentType",
            ),
        ),
        migrations.AlterField(
            model_name="notification",
            name="action_object_object_id",
            field=models.PositiveIntegerField(
                blank=True,
                db_comment="The unique ID of the action object associated with the notification, if applicable.",
                help_text="The ID of the action object.",
                null=True,
                verbose_name="Action object ID",
            ),
        ),
        migrations.AlterField(
            model_name="notification",
            name="actor_content_type",
            field=models.ForeignKey(
                db_comment="The content type of the object representing the actor (i.e., the initiator of the notification).",
                help_text="The content type of the actor object.",
                on_delete=django.db.models.deletion.CASCADE,
                related_name="actor_content_type_notifications",
                to="contenttypes.contenttype",
                verbose_name="Actor ContentType",
            ),
        ),
        migrations.AlterField(
            model_name="notification",
            name="actor_object_id",
            field=models.PositiveIntegerField(
                db_comment="The unique ID of the actor object associated with the notification.",
                help_text="The ID of the actor object.",
                verbose_name="Actor object ID",
            ),
        ),
        migrations.AlterField(
            model_name="notification",
            name="data",
            field=models.JSONField(
                blank=True,
                db_comment="Stores arbitrary JSON data related to the notification, such as custom attributes or metadata.",
                help_text="Additional metadata or custom attributes in JSON format.",
                null=True,
                verbose_name="data",
            ),
        ),
        migrations.AlterField(
            model_name="notification",
            name="description",
            field=models.TextField(
                blank=True,
                db_comment="A textual description providing more detail about the notification.",
                help_text="The description of the notification.",
                max_length=512,
                null=True,
                verbose_name="Description",
            ),
        ),
        migrations.AlterField(
            model_name="notification",
            name="is_sent",
            field=models.BooleanField(
                db_comment="A boolean flag indicating whether this notification has already been sent to its recipients.",
                default=False,
                help_text="indicate whether the notification has been sent.",
                verbose_name="Is sent",
            ),
        ),
        migrations.AlterField(
            model_name="notification",
            name="link",
            field=models.URLField(
                blank=True,
                db_comment="A URL related to the notification or action, for further details or follow-up.",
                help_text="A URL associated with the action.",
                null=True,
                verbose_name="Link",
            ),
        ),
        migrations.AlterField(
            model_name="notification",
            name="public",
            field=models.BooleanField(
                db_comment="A boolean flag indicating if this notification is public or private.",
                default=True,
                help_text="Indicate whether the notification is public.",
                verbose_name="Public",
            ),
        ),
        migrations.AlterField(
            model_name="notification",
            name="status",
            field=models.CharField(
                choices=[
                    (
                        "ERROR",
                        "Error - Indicates critical errors that require immediate attention",
                    ),
                    (
                        "SUCCESS",
                        "Success - Indicates successful completion of an operation",
                    ),
                    (
                        "WARNING",
                        "Warning - Indicates potential issues or concerns that should be addressed",
                    ),
                    ("INFO", "Information - Provides general informational messages"),
                    (
                        "CRITICAL",
                        "Critical - Indicates critical issues that may impact functionality",
                    ),
                    (
                        "SENSITIVE",
                        "Sensitive - Indicates notifications related to sensitive data",
                    ),
                    (
                        "INFRASTRUCTURE",
                        "Infrastructure - Indicates notifications related to system infrastructure",
                    ),
                ],
                db_comment="Indicates the notification's current status, such as 'info', 'error', or 'warning'.",
                default="INFO",
                help_text="The current status of the notification.",
                max_length=15,
                verbose_name="Status",
            ),
        ),
        migrations.AlterField(
            model_name="notification",
            name="target_content_type",
            field=models.ForeignKey(
                blank=True,
                db_comment="The content type of the target object of the notification, if applicable.",
                help_text="The content type of the target object.",
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="target_content_type_notifications",
                to="contenttypes.contenttype",
                verbose_name="Target ContentType",
            ),
        ),
        migrations.AlterField(
            model_name="notification",
            name="target_object_id",
            field=models.PositiveIntegerField(
                blank=True,
                db_comment="The unique ID of the target object associated with the notification, if applicable.",
                help_text="The ID of the target object.",
                null=True,
                verbose_name="Target object ID",
            ),
        ),
        migrations.AlterField(
            model_name="notification",
            name="timestamp",
            field=models.DateTimeField(
                db_comment="The date and time when this notification was created.",
                db_index=True,
                default=django.utils.timezone.now,
                help_text="The time when the notification was created.",
                verbose_name="Timestamp",
            ),
        ),
        migrations.AlterField(
            model_name="notification",
            name="verb",
            field=models.CharField(
                db_comment="A short description of the action that triggered the notification (e.g., 'liked', 'commented').",
                help_text="The action verb associated with the notification, e.g., 'liked', 'commented'.",
                max_length=127,
                verbose_name="Verb",
            ),
        ),
        migrations.AlterField(
            model_name="notificationrecipient",
            name="notification",
            field=models.ForeignKey(
                db_comment="Foreign key linking to the Notification model, representing the notification that is being sent to the recipient.",
                help_text="The notification that is being sent.",
                on_delete=django.db.models.deletion.CASCADE,
                related_name="notification_recipients",
                to="django_notification.notification",
                verbose_name="Notification",
            ),
        ),
        migrations.AlterField(
            model_name="notificationrecipient",
            name="recipient",
            field=models.ForeignKey(
                db_comment="Foreign key linking to the User model (AUTH_USER_MODEL), representing the recipient of the notification.",
                help_text="The user who will receive the notification.",
                on_delete=django.db.models.deletion.CASCADE,
                related_name="received_notifications",
                to=settings.AUTH_USER_MODEL,
                verbose_name="Recipient",
            ),
        ),
        migrations.AlterField(
            model_name="notificationseen",
            name="notification",
            field=models.ForeignKey(
                db_comment="Foreign key linking to the Notification model, representing the notification that was viewed by the user.",
                help_text="The notification that was seen.",
                on_delete=django.db.models.deletion.CASCADE,
                related_name="seen",
                to="django_notification.notification",
                verbose_name="Notification",
            ),
        ),
        migrations.AlterField(
            model_name="notificationseen",
            name="seen_at",
            field=models.DateTimeField(
                db_comment="A timestamp recording when the notification was marked as seen by the user.",
                default=django.utils.timezone.now,
                help_text="The time that the notification was seen.",
                verbose_name="Seen at",
            ),
        ),
        migrations.AlterField(
            model_name="notificationseen",
            name="user",
            field=models.ForeignKey(
                db_comment="Foreign key linking to the User model (AUTH_USER_MODEL), representing the user who has viewed the notification.",
                help_text="The recipient or a group member who has seen the notification.",
                on_delete=django.db.models.deletion.CASCADE,
                related_name="seen_notifications",
                to=settings.AUTH_USER_MODEL,
                verbose_name="User",
            ),
        ),
    ]
